'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

var _passport = require('passport');

var _passport2 = _interopRequireDefault(_passport);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (req, res, next) {
  var sails = req._sails;

  var returnUnauthenticated = function returnUnauthenticated() {
    // Set status code
    res.statusCode = 401;

    if (sails.config.simpleauth.isNotAuthenticatedMessage) {
      var error = new Error(sails.config.simpleauth.isNotAuthenticatedMessage);
      error.code = 'E_AUTHORIZATION';
      return res.forbidden(error);
    }

    if (req.isSocket) return res.forbidden();

    return res.redirect(sails.config.simpleauth.isNotAuthenticatedRedirect);
  };

  var isAuthenticated = function isAuthenticated() {
    // Check if user logged in
    if (req.isAuthenticated()) {
      req.session._garbage = Date();
      req.session.touch();

      return next();
    }

    // Client is unauthenticated
    return returnUnauthenticated();
  };

  if (req.isSocket) {
    if (req.session && req.session.passport && req.session.passport.user) {
      _.extend(req, _.pick(_http2.default.IncomingMessage.prototype, 'login', 'logIn', 'logout', 'logOut', 'isAuthenticated', 'isUnauthenticated'));

      return _passport2.default.initialize()(req, res, function () {
        _passport2.default.session()(req, res, function () {
          return isAuthenticated();
        });
      });
    }

    // Client is unauthenticated
    return returnUnauthenticated();
  }

  return isAuthenticated();
};

module.exports = exports['default'];