'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; /**
                                                                                                                                                                                                                                                                               * Hook dependencies
                                                                                                                                                                                                                                                                               */


exports.default = simpleAuth;

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _passport = require('passport');

var _passport2 = _interopRequireDefault(_passport);

var _injectCustomPolicies = require('./utils/injectCustomPolicies');

var _injectCustomPolicies2 = _interopRequireDefault(_injectCustomPolicies);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function simpleAuth(sails) {
  return {
    /**
     * Hook defaults
     */
    defaults: {

      __configKey__: {
        passport: {
          serializeUser: function serializeUser(user, done) {
            done(null, user.id);
          },
          deserializeUser: function deserializeUser(id, done) {
            User.findOne({ id: id }, function (err, user) {
              done(err, user);
            });
          },
          strategies: {}
        },
        isNotAuthenticatedRedirect: '/login'
      }
    },

    /**
     * Hook configuration
     */
    configure: function configure() {
      var that = this;
      var config = sails.config[that.configKey];

      // If the http hook was found
      if (sails.hooks.http) {
        // Add the http middleware 'passportInit' if no custom middleware exists
        if (_lodash2.default.isUndefined(sails.config.http.middleware.passportInit)) {
          sails.config.http.middleware.passportInit = _passport2.default.initialize();
        }

        // Add the http middleware 'passportSession' if no custom middleware exists
        if (_lodash2.default.isUndefined(sails.config.http.middleware.passportSession)) {
          sails.config.http.middleware.passportSession = _passport2.default.session();
        }

        // Update middleware order
        if (sails.config.http.middleware.order.indexOf('session') !== -1) {
          sails.config.http.middleware.order.splice(sails.config.http.middleware.order.indexOf('session') + 1, 0, 'passportInit', 'passportSession');
        } else if (sails.config.http.middleware.order.indexOf('cookieParser') !== -1) {
          sails.config.http.middleware.order.splice(sails.config.http.middleware.order.indexOf('cookieParser') + 1, 0, 'passportInit', 'passportSession');
        } else {
          sails.config.http.middleware.order.splice(0, 0, 'passportInit', 'passportSession');
        }

        if (config.passport) {
          if (config.passport.serializeUser && typeof config.passport.serializeUser === 'function') {
            _passport2.default.serializeUser(config.passport.serializeUser);
          }

          if (config.passport.deserializeUser && typeof config.passport.deserializeUser === 'function') {
            _passport2.default.deserializeUser(config.passport.deserializeUser);
          }

          if (config.passport.strategies && _typeof(config.passport.strategies) === 'object') {
            _lodash2.default.each(config.passport.strategies, function (strategy, name) {
              if (strategy.strategy && typeof strategy.strategy === 'function' && strategy.verify && typeof strategy.verify === 'function') {
                _passport2.default.use(name, new strategy.strategy(_lodash2.default.merge({}, strategy.options), strategy.verify));
              }
            });
          }
        }
      }
    },


    /**
     * Hook initialization
     *
     * @param  {Function} cb
     */
    initialize: function initialize(cb) {
      // Only if the http and policies hook was found
      if (sails.hooks.http && sails.hooks.policies) {
        // Inject custom policies
        return (0, _injectCustomPolicies2.default)(sails, function customPoliciesInjected(err) {
          if (err) return cb(err);

          // Hook loaded
          return cb();
        });
      } else {
        // Hook loaded, but without changes
        return cb();
      }
    }
  };
}
module.exports = exports['default'];