'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = injectCustomPolicies;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _includeAll = require('include-all');

var _includeAll2 = _interopRequireDefault(_includeAll);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Inject custom api policies.
 *
 * @param {Object} sails
 * @param {Function} cb
 */
function injectCustomPolicies(sails, cb) {
  _includeAll2.default.optional({
    dirname: _path2.default.resolve(__dirname, '../api/policies'),
    filter: new RegExp('(.+)\\.(' + sails.config.moduleloader.sourceExt.join('|') + ')$'),
    replaceExpr: null,
    flatten: true,
    keepDirectoryPath: true
  }, function customPoliciesLoaded(err, customPolicies) {

    if (err) return cb(err);

    // If some custom policies found
    if (_lodash2.default.size(customPolicies)) {
      // Load default policies
      sails.modules.loadPolicies(function defaultPoliciesLoaded(innerErr, defaultPolicies) {
        if (innerErr) return cb(innerErr);

        // Add custom policies
        _lodash2.default.each(customPolicies, function (customPolicy, name) {
          // Bind and add custom policy (only if we could not find a default policy with the same name)
          if (_lodash2.default.isUndefined(defaultPolicies[name])) {
            // Add a reference to the Sails app that loaded the policy
            customPolicy.sails = sails;

            // Bind all methods to the policy context
            _lodash2.default.bindAll(customPolicy);

            // Add custom policy
            sails.hooks.policies.middleware[name] = customPolicy;
          }
        });

        return cb();
      });
    } else {
      return cb();
    }
  });
} /**
   * Util dependencies
   */
module.exports = exports['default'];